@@ -1,5 +1,6 @@
 from datetime import datetime
 
+from .exceptions import NeighbourhoodsNeighbourhoodException
 from .resource import Resource, SimpleResource
 
 
@@ -59,6 +60,12 @@ class Neighbourhood(Resource):
 
         _hydrate_action_date = _hydrate_issue_date
 
+    def __init__(self, *args, **kwargs):
+        super(Neighbourhood, self).__init__(*args, **kwargs)
+
+        if self.id == 'neighbourhoods':
+            raise NeighbourhoodsNeighbourhoodException()
+
     def __str__(self):
         return '<Neighbourhood> %s' % self.id
 
